# Logic

> see https://aka.ms/autorest

This is the AutoRest configuration file for Logic.

---

## Getting Started

To build the SDK for Logic, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration

### Basic Information

These are the global settings for the Logic API.

``` yaml
openapi-type: arm
tag: package-2018-07-preview

directive:
  - where:
      - $.paths["/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Logic/workflows/{workflowName}/runs/{runName}/actions/{actionName}/listExpressionTraces"].post.responses["200"].schema
    suppress:
      - CollectionObjectPropertiesNaming
  - where:
      - $.paths["/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Logic/workflows/{workflowName}/runs/{runName}/actions/{actionName}/repetitions/{repetitionName}/listExpressionTraces"].post.responses["200"].schema
    suppress:
      - CollectionObjectPropertiesNaming

```

### Tag: package-2018-07-preview

These settings apply only when `--package-2018-07-preview` is specified on the command line.

``` yaml $(tag) == 'package-2018-07-preview'
input-file:
- Microsoft.Logic/preview/2018-07-01-preview/logic.json
```

## Suppression

``` yaml
directive:
  - suppress: R3016
    reason: Existing properties, can't be changed without breaking API.
    #where:
    #  - $.definitions.AS2ErrorSettings.properties.resendIfMDNNotReceived
    #  - $.definitions.AS2MdnSettings.properties.needMDN
    #  - $.definitions.AS2MdnSettings.properties.signMDN
    #  - $.definitions.AS2MdnSettings.properties.sendMDNAsynchronously
    #  - $.definitions.AS2MdnSettings.properties.signOutboundMDNIfOptional
    #  - $.definitions.AS2MdnSettings.properties.sendInboundMDNToMessageBox
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForInboundEncodedMessages
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForInboundDecodedMessages
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForOutboundMDN
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForOutboundEncodedMessages
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForOutboundDecodedMessages
    #  - $.definitions.AS2SecuritySettings.properties.enableNRRForInboundMDN
    #  - $.definitions.EdifactValidationSettings.properties.validateEDITypes
    #  - $.definitions.EdifactValidationSettings.properties.validateXSDTypes
    #  - $.definitions.EdifactValidationOverride.properties.validateEDITypes
    #  - $.definitions.EdifactValidationOverride.properties.validateXSDTypes
    #  - $.definitions.X12ValidationSettings.properties.validateEDITypes
    #  - $.definitions.X12ValidationSettings.properties.validateXSDTypes
    #  - $.definitions.X12ValidationOverride.properties.validateEDITypes
    #  - $.definitions.X12ValidationOverride.properties.validateXSDTypes

```

### Tag: package-2016-06

These settings apply only when `--tag=package-2016-06` is specified on the command line.

``` yaml $(tag) == 'package-2016-06'
input-file:
- Microsoft.Logic/stable/2016-06-01/logic.json
```

### Tag: package-2015-08-preview

These settings apply only when `--tag=package-2015-08-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-08-preview'
input-file:
- Microsoft.Logic/preview/2015-08-01-preview/logic.json
```

### Tag: package-2015-02-preview

These settings apply only when `--tag=package-2015-02-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-02-preview'
input-file:
- Microsoft.Logic/preview/2015-02-01-preview/logic.json
```

---

# Code Generation

## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-js
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_logic']
```

## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.Logic
  output-folder: $(csharp-sdks-folder)/Logic/Management.Logic/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.logic
  package-name: azure-mgmt-logic
  clear-output-folder: true
```

``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-logic/azure/mgmt/logic
```

``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-logic
```

## Go

See configuration in [readme.go.md](./readme.go.md)

## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
azure-arm: true
fluent: true
namespace: com.microsoft.azure.management.logic
license-header: MICROSOFT_MIT_NO_CODEGEN
payload-flattening-threshold: 1
output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-logic
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2018-07-preview
  - tag: package-2016-06
```

### Tag: package-2018-07-preview and java

These settings apply only when `--tag=package-2018-07-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2018-07-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.logic.v2018_07_01_preview
  output-folder: $(azure-libraries-for-java-folder)/logic/resource-manager/v2018_07_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-06 and java

These settings apply only when `--tag=package-2016-06 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-06' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.logic.v2016_06_01
  output-folder: $(azure-libraries-for-java-folder)/logic/resource-manager/v2016_06_01
regenerate-manager: true
generate-interface: true
```
